@@ -1,7 +1,7 @@
 """
 Convenience methods for Cocoa mapping types.
 """
-__all__ = ('addConvenienceForBasicMapping',)
+__all__ = ("addConvenienceForBasicMapping",)
 
 from objc._objc import selector
 from objc._convenience import addConvenienceForClass, CLASS_ABC
@@ -13,6 +13,7 @@ if sys.version_info[0] == 2:
 else:
     import collections.abc as collections_abc
 
+
 def __getitem__objectForKey_(self, key):
     res = self.objectForKey_(container_wrap(key))
     return container_unwrap(res, KeyError, key)
@@ -31,31 +32,25 @@ def contains_objectForKey_(self, key):
 
 
 _CONVENIENCES_MAPPING_RO = (
-    ('__getitem__', __getitem__objectForKey_),
-    ('get', get_objectForKey_),
-    ('__contains__', contains_objectForKey_),
+    ("__getitem__", __getitem__objectForKey_),
+    ("get", get_objectForKey_),
+    ("__contains__", contains_objectForKey_),
 )
 
-if sys.version_info[0] == 2: # pragma: no 3.x cover; pragma: no branch
-    _CONVENIENCES_MAPPING_RO += (
-        ('has_key', contains_objectForKey_),
-    )
-
-
 def __delitem__removeObjectForKey_(self, key):
     self.removeObjectForKey_(container_wrap(key))
 
+
 def update_setObject_forKey_(self, *args, **kwds):
     # XXX - should this be more flexible?
     if len(args) == 0:
         pass
     elif len(args) != 1:
-        raise TypeError("update expected at most 1 arguments, got {0}".format(
-            len(args)))
+        raise TypeError("update expected at most 1 arguments, got {0}".format(len(args)))
 
     else:
         other = args[0]
-        if hasattr(other, 'keys'):
+        if hasattr(other, "keys"):
             # This mirrors the implementation of dict.update, but seems
             # wrong for Python3 (with collectons.abc.Dict)
             for key in other.keys():
@@ -81,7 +76,9 @@ def __setitem__setObject_forKey_(self, key, value):
     self.setObject_forKey_(container_wrap(value), container_wrap(key))
 
 
-_pop_setObject_dflt=object()
+_pop_setObject_dflt = object()
+
+
 def pop_setObject_forKey_(self, key, dflt=_pop_setObject_dflt):
     try:
         res = self[key]
@@ -107,12 +104,12 @@ def popitem_setObject_forKey_(self):
 
 
 _CONVENIENCES_MAPPING_RW = _CONVENIENCES_MAPPING_RO + (
-    ('__delitem__', __delitem__removeObjectForKey_),
-    ('__setitem__', __setitem__setObject_forKey_),
-    ('update', update_setObject_forKey_),
-    ('setdefault', setdefault_setObject_forKey_),
-    ('pop', pop_setObject_forKey_),
-    ('popitem', popitem_setObject_forKey_),
+    ("__delitem__", __delitem__removeObjectForKey_),
+    ("__setitem__", __setitem__setObject_forKey_),
+    ("update", update_setObject_forKey_),
+    ("setdefault", setdefault_setObject_forKey_),
+    ("pop", pop_setObject_forKey_),
+    ("popitem", popitem_setObject_forKey_),
 )
 
 
@@ -123,8 +120,9 @@ def addConvenienceForBasicMapping(classname, readonly=True):
     Used to add the basic collections.abc.Mapping or collections.abc.MutableMapping
     APIs to a Cocoa class that has an API simular to NSDictionary.
     """
-    addConvenienceForClass(classname,
-        _CONVENIENCES_MAPPING_RO if readonly else _CONVENIENCES_MAPPING_RW)
+    addConvenienceForClass(
+        classname, _CONVENIENCES_MAPPING_RO if readonly else _CONVENIENCES_MAPPING_RW
+    )
 
     try:
         lst = CLASS_ABC[classname]
