@@ -3,11 +3,12 @@
 
 @implementation OC_BuiltinPythonNumber
 
-+ (BOOL)supportsSecureCoding {
++ (BOOL)supportsSecureCoding
+{
     return YES;
 }
 
-+(NSArray*)classFallbacksForKeyedArchiver
++ (NSArray*)classFallbacksForKeyedArchiver
 {
     return [NSArray arrayWithObjects:@"OC_PythonNumber", @"NSNumber", nil];
 }
