@@ -1,21 +1,20 @@
 #include "pyobjc.h"
 #import "OC_NSBundleHack.h"
-#import "objc_util.h"
 
 static id (*bundleForClassIMP)(id, SEL, Class);
 
 @implementation OC_NSBundleHackCheck
-+(NSBundle*)bundleForClass
++ (NSBundle*)bundleForClass
 {
     return [NSBundle bundleForClass:[NSObject class]];
 }
 @end
 
 @implementation OC_NSBundleHack
-+(NSBundle*)bundleForClass:(Class)aClass
++ (NSBundle*)bundleForClass:(Class)aClass
 {
-static NSBundle* mainBundle = nil;
-static NSMapTable* bundleCache = nil;
+    static NSBundle* mainBundle = nil;
+    static NSMapTable* bundleCache = nil;
     id rval;
 
     if (unlikely(!mainBundle)) {
@@ -23,17 +22,16 @@ static NSMapTable* bundleCache = nil;
     }
 
     if (unlikely(!bundleCache)) {
-        bundleCache = NSCreateMapTable(
-            PyObjCUtil_PointerKeyCallBacks,
-            PyObjCUtil_ObjCValueCallBacks,
-            PYOBJC_EXPECTED_CLASS_COUNT);
+        bundleCache =
+            NSCreateMapTable(PyObjCUtil_PointerKeyCallBacks,
+                             PyObjCUtil_ObjCValueCallBacks, PYOBJC_EXPECTED_CLASS_COUNT);
     }
 
     if (!aClass) {
         return mainBundle;
     }
 
-    rval = (id)NSMapGet(bundleCache, (const void *)aClass);
+    rval = (id)NSMapGet(bundleCache, (const void*)aClass);
     if (rval) {
         return rval;
     }
@@ -59,35 +57,33 @@ static NSMapTable* bundleCache = nil;
         }
     }
 
-    NSMapInsert(bundleCache, (const void *)aClass, (const void *)rval);
+    NSMapInsert(bundleCache, (const void*)aClass, (const void*)rval);
     return rval;
 }
 
-static const char BUNDLE_FOR_CLASS_SIGNATURE[] = { _C_ID, _C_ID, _C_SEL, _C_CLASS, 0 };
+static const char BUNDLE_FOR_CLASS_SIGNATURE[] = {_C_ID, _C_ID, _C_SEL, _C_CLASS, 0};
 
-+(void)installBundleHack
++ (void)installBundleHack
 {
-    if ([[NSBundle bundleForClass:[NSObject class]] isEqual:[NSBundle bundleForClass:[OC_NSBundleHackCheck class]]]) {
+    if ([[NSBundle bundleForClass:[NSObject class]]
+            isEqual:[NSBundle bundleForClass:[OC_NSBundleHackCheck class]]]) {
         // implementation is already fine
         return;
     }
 
-    bundleForClassIMP = (id (*)(id, SEL, Class))[NSBundle methodForSelector:@selector(bundleForClass:)];
+    bundleForClassIMP =
+        (id(*)(id, SEL, Class))[NSBundle methodForSelector:@selector(bundleForClass:)];
 
-    Method method = class_getInstanceMethod(
-        object_getClass([NSBundle class]),
-        @selector(bundleForClass:));
+    Method method = class_getInstanceMethod(object_getClass([NSBundle class]),
+                                            @selector(bundleForClass:));
 
     if (method == NULL) {
-        class_addMethod(
-            object_getClass([NSBundle class]),
-            @selector(bundleForClass:),
-            [self methodForSelector:@selector(bundleForClass:)],
-            BUNDLE_FOR_CLASS_SIGNATURE);
+        class_addMethod(object_getClass([NSBundle class]), @selector(bundleForClass:),
+                        [self methodForSelector:@selector(bundleForClass:)],
+                        BUNDLE_FOR_CLASS_SIGNATURE);
     } else {
         method_setImplementation(method,
-            [self methodForSelector:@selector(bundleForClass:)]
-        );
+                                 [self methodForSelector:@selector(bundleForClass:)]);
     }
 }
 @end
