@@ -2,7 +2,8 @@
 #define PyObjC_INFORMAL_PROTOCOL_H
 
 extern PyTypeObject PyObjCInformalProtocol_Type;
-#define PyObjCInformalProtocol_Check(obj) PyObject_TypeCheck(obj, &PyObjCInformalProtocol_Type)
+#define PyObjCInformalProtocol_Check(obj)                                                \
+    PyObject_TypeCheck(obj, &PyObjCInformalProtocol_Type)
 
 extern int PyObjCInformalProtocol_CheckClass(PyObject*, char*, PyObject*, PyObject*);
 extern PyObject* PyObjCInformalProtocol_FindSelector(PyObject*, SEL, int);
