@@ -1,10 +1,8 @@
 #ifndef OBJC_UTIL
 #define OBJC_UTIL
 
-#if PY_MAJOR_VERSION == 3
 extern PyObject* PyObjCDict_GetItemStringWithError(PyObject* dict, const char* key);
 #define PyDict_GetItemStringWithError PyObjCDict_GetItemStringWithError
-#endif
 
 extern PyObject* PyObjCExc_Error;
 extern PyObject* PyObjCExc_NoSuchClassError;
@@ -19,14 +17,16 @@ extern PyObject* PyObjCExc_ObjCPointerWarning;
 
 extern int PyObjCUtil_Init(PyObject* module);
 
-extern void PyObjCErr_FromObjC(NSException* localException);
+extern void PyObjCErr_FromObjC(NSObject* localException);
 extern void PyObjCErr_ToObjC(void) __attribute__((__noreturn__));
 
-extern void PyObjCErr_ToObjCWithGILState(PyGILState_STATE* state) __attribute__((__noreturn__));
+extern void PyObjCErr_ToObjCWithGILState(PyGILState_STATE* state)
+    __attribute__((__noreturn__));
 
 extern NSException* PyObjCErr_AsExc(void);
 
-extern PyObject* PyObjC_CallPython(id self, SEL selector, PyObject* arglist, BOOL* isAlloc, BOOL* isCFAlloc);
+extern PyObject* PyObjC_CallPython(id self, SEL selector, PyObject* arglist,
+                                   BOOL* isAlloc, BOOL* isCFAlloc);
 
 extern char* PyObjCUtil_Strdup(const char* value);
 
@@ -37,9 +37,11 @@ extern NSMapTableKeyCallBacks PyObjCUtil_ObjCIdentityKeyCallBacks;
 extern NSMapTableValueCallBacks PyObjCUtil_ObjCValueCallBacks;
 
 extern void PyObjC_FreeCArray(int, void*);
-extern int PyObjC_PythonToCArray(BOOL, BOOL, const char*, PyObject*, void**, Py_ssize_t*, PyObject**);
+extern int PyObjC_PythonToCArray(BOOL, BOOL, const char*, PyObject*, void**, Py_ssize_t*,
+                                 PyObject**);
 extern PyObject* PyObjC_CArrayToPython(const char*, void*, Py_ssize_t);
-extern PyObject* PyObjC_CArrayToPython2(const char*, void*, Py_ssize_t, bool already_retained, bool already_cfretained);
+extern PyObject* PyObjC_CArrayToPython2(const char*, void*, Py_ssize_t,
+                                        bool already_retained, bool already_cfretained);
 extern int PyObjC_IsPythonKeyword(const char* word) __attribute__((__pure__));
 
 extern int PyObjCRT_SimplifySignature(const char* signature, char* buf, size_t buflen);
@@ -47,8 +49,10 @@ extern int PyObjCRT_SimplifySignature(const char* signature, char* buf, size_t b
 extern int PyObjCObject_Convert(PyObject* object, void* pvar);
 extern int PyObjCClass_Convert(PyObject* object, void* pvar);
 
-extern int PyObjC_is_ascii_string(PyObject* unicode_string, const char* ascii_string) __attribute__((__pure__));
-extern int PyObjC_is_ascii_prefix(PyObject* unicode_string, const char* ascii_string, size_t n) __attribute__((__pure__));
+extern int PyObjC_is_ascii_string(PyObject* unicode_string, const char* ascii_string)
+    __attribute__((__pure__));
+extern int PyObjC_is_ascii_prefix(PyObject* unicode_string, const char* ascii_string,
+                                  size_t n) __attribute__((__pure__));
 
 extern PyObject* PyObjC_ImportName(const char* name);
 
@@ -59,10 +63,12 @@ extern int PyObjCRT_SignaturesEqual(const char*, const char*) __attribute__((__p
 
 extern char* PyObjC_SELToPythonName(SEL, char*, size_t);
 
-static inline Py_ssize_t align(Py_ssize_t offset, Py_ssize_t alignment)
+static inline Py_ssize_t
+align(Py_ssize_t offset, Py_ssize_t alignment)
 {
     Py_ssize_t rest = offset % alignment;
-    if (rest == 0) return offset;
+    if (rest == 0)
+        return offset;
     return offset + (alignment - rest);
 }
 
@@ -73,12 +79,12 @@ static inline Py_ssize_t align(Py_ssize_t offset, Py_ssize_t alignment)
  *
  *    use this instead of 'Py_XDECREF(op); op = value'
  */
-#define SET_FIELD(op, value)                    \
-    do {                                        \
-        PyObject* _py_tmp = (PyObject*)(op);    \
-        (op) = value;                           \
-        Py_XDECREF(_py_tmp);                    \
-    } while(0)
+#define SET_FIELD(op, value)                                                             \
+    do {                                                                                 \
+        PyObject* _py_tmp = (PyObject*)(op);                                             \
+        (op) = value;                                                                    \
+        Py_XDECREF(_py_tmp);                                                             \
+    } while (0)
 
 /*
  * SET_FIELD_INCREF(op, value):
@@ -86,13 +92,13 @@ static inline Py_ssize_t align(Py_ssize_t offset, Py_ssize_t alignment)
  *
  *    use this instead of 'Py_XDECREF(op); Py_INCREF(value); op = value'
  */
-#define SET_FIELD_INCREF(op, value)             \
-    do {                                        \
-        PyObject* _py_tmp = (PyObject*)(op);    \
-        PyObject* _py_val = (PyObject*)(value); \
-        Py_XINCREF(_py_val);                    \
-        (op) = _py_val;                         \
-        Py_XDECREF(_py_tmp);                    \
-    } while(0)
+#define SET_FIELD_INCREF(op, value)                                                      \
+    do {                                                                                 \
+        PyObject* _py_tmp = (PyObject*)(op);                                             \
+        PyObject* _py_val = (PyObject*)(value);                                          \
+        Py_XINCREF(_py_val);                                                             \
+        (op) = _py_val;                                                                  \
+        Py_XDECREF(_py_tmp);                                                             \
+    } while (0)
 
 #endif /* OBJC_UTIL */
