@@ -2,42 +2,39 @@
 #include "Python.h"
 #include "pyobjc-api.h"
 
-#import <Foundation/Foundation.h>
 #import <CoreFoundation/CoreFoundation.h>
+#import <Foundation/Foundation.h>
 
-
-@interface OC_TestCoreFoundation : NSObject
-{
+@interface OC_TestCoreFoundation : NSObject {
 }
 // not toll-free bridged.
-+(char*)signatureForCFUUIDRef;
-+(CFTypeID)typeidForCFUUIDRef;
-+(CFUUIDRef)createUUID;
-+(NSString*)formatUUID:(CFUUIDRef)uuid;
-+(NSObject*)anotherUUID;
++ (char*)signatureForCFUUIDRef;
++ (CFTypeID)typeidForCFUUIDRef;
++ (CFUUIDRef)createUUID;
++ (NSString*)formatUUID:(CFUUIDRef)uuid;
++ (NSObject*)anotherUUID;
 
 // tollfree bridged:
-+(char*)signatureForCFDateRef;
-+(CFTypeID)typeidForCFDateRef;
-+(CFDateRef)today;
-+(NSString*)formatDate:(CFDateRef)date;
-+(int)shortStyle;
++ (char*)signatureForCFDateRef;
++ (CFTypeID)typeidForCFDateRef;
++ (CFDateRef)today;
++ (NSString*)formatDate:(CFDateRef)date;
++ (int)shortStyle;
 @end
 
-
 @implementation OC_TestCoreFoundation
 
-+(char*)signatureForCFUUIDRef
++ (char*)signatureForCFUUIDRef
 {
     return @encode(CFUUIDRef);
 }
 
-+(CFTypeID)typeidForCFUUIDRef
++ (CFTypeID)typeidForCFUUIDRef
 {
     return CFUUIDGetTypeID();
 }
 
-+(CFUUIDRef)createUUID
++ (CFUUIDRef)createUUID
 {
     CFUUIDRef result = CFUUIDCreate(NULL);
 
@@ -49,7 +46,7 @@
     return result;
 }
 
-+(NSObject*)anotherUUID
++ (NSObject*)anotherUUID
 {
     CFUUIDRef result = CFUUIDCreate(NULL);
 
@@ -59,8 +56,7 @@
     return (NSObject*)result;
 }
 
-
-+(NSString*)formatUUID:(CFUUIDRef)uuid
++ (NSString*)formatUUID:(CFUUIDRef)uuid
 {
     NSString* result;
 
@@ -68,19 +64,17 @@
     return [result autorelease];
 }
 
-
-
-+(char*)signatureForCFDateRef
++ (char*)signatureForCFDateRef
 {
     return @encode(CFDateRef);
 }
 
-+(CFTypeID)typeidForCFDateRef
++ (CFTypeID)typeidForCFDateRef
 {
     return CFDateGetTypeID();
 }
 
-+(CFDateRef)today
++ (CFDateRef)today
 {
     CFDateRef result;
 
@@ -92,89 +86,61 @@
     return result;
 }
 
-+(NSString*)formatDate:(CFDateRef)date
++ (NSString*)formatDate:(CFDateRef)date
 {
     CFLocaleRef currentLocale = CFLocaleCopyCurrent();
     CFDateFormatterRef formatter = CFDateFormatterCreate(
-            NULL, currentLocale,
-            kCFDateFormatterShortStyle, kCFDateFormatterNoStyle);
+        NULL, currentLocale, kCFDateFormatterShortStyle, kCFDateFormatterNoStyle);
 
     if (currentLocale != NULL) {
         CFRelease(currentLocale);
     }
 
-    NSString* result = (NSString*)CFDateFormatterCreateStringWithDate(
-            NULL, formatter, date);
+    NSString* result =
+        (NSString*)CFDateFormatterCreateStringWithDate(NULL, formatter, date);
 
     CFRelease(formatter);
     return [result autorelease];
 }
 
-+(int)shortStyle
++ (int)shortStyle
 {
     return kCFDateFormatterShortStyle;
 }
 
 @end
 
+static PyMethodDef mod_methods[] = {{0, 0, 0, 0}};
 
-
-static PyMethodDef mod_methods[] = {
-            { 0, 0, 0, 0 }
-};
-#if PY_VERSION_HEX >= 0x03000000
-
-static struct PyModuleDef mod_module = {
-    PyModuleDef_HEAD_INIT,
-    "corefoundation",
-    NULL,
-    0,
-    mod_methods,
-    NULL,
-    NULL,
-    NULL,
-    NULL
-};
-
-#define INITERROR() return NULL
-#define INITDONE() return m
+static struct PyModuleDef mod_module = {PyModuleDef_HEAD_INIT,
+                                        "corefoundation",
+                                        NULL,
+                                        0,
+                                        mod_methods,
+                                        NULL,
+                                        NULL,
+                                        NULL,
+                                        NULL};
 
 PyObject* PyInit_corefoundation(void);
 
-PyObject* __attribute__((__visibility__("default")))
-PyInit_corefoundation(void)
-
-#else
-
-#define INITERROR() return
-#define INITDONE() return
-
-void initcorefoundation(void);
-
-void __attribute__((__visibility__("default")))
-initcorefoundation(void)
-#endif
+PyObject* __attribute__((__visibility__("default"))) PyInit_corefoundation(void)
 {
     PyObject* m;
 
-#if PY_VERSION_HEX >= 0x03000000
     m = PyModule_Create(&mod_module);
-#else
-    m = Py_InitModule4("corefoundation", mod_methods,
-        NULL, NULL, PYTHON_API_VERSION);
-#endif
     if (!m) {
-        INITERROR();
+        return NULL;
     }
 
     if (PyObjC_ImportAPI(m) < 0) {
-        INITERROR();
+        return NULL;
     }
 
     if (PyModule_AddObject(m, "OC_TestCoreFoundation",
-        PyObjC_IdToPython([OC_TestCoreFoundation class])) < 0) {
-        INITERROR();
+                           PyObjC_IdToPython([OC_TestCoreFoundation class])) < 0) {
+        return NULL;
     }
 
-    INITDONE();
+    return m;
 }
