@@ -3,6 +3,7 @@ from PyObjCTools.TestSupport import *
 import objc
 import sys
 
+
 class TestAllocateBuffer(TestCase):
     def testBadLengths(self):
         self.assertRaises(ValueError, objc.allocateBuffer, 0)
@@ -13,19 +14,20 @@ class TestAllocateBuffer(TestCase):
         self.assertEqual(len(b), 10000)
 
         if sys.version_info[0] == 2:
-            for i in range(0,10000):
+            for i in range(0, 10000):
                 b[i] = chr(i % 256)
 
             b[5:10] = b[1:6]
-            b[5:10] = 'abcde'
+            b[5:10] = "abcde"
             try:
-                b[5:10] = 'abcdefghijk'
+                b[5:10] = "abcdefghijk"
             except TypeError as r:
-                if str(r).find("right operand length must match slice length") is not 0:
+                if str(r).find("right operand length must match slice length") != 0:
                     raise
 
         else:
             self.assertIsInstance(b, bytearray)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
