@@ -25,23 +25,32 @@ else:
 MYDIR = os.path.dirname(os.path.abspath(__file__))
 
 
-NSArray = objc.lookUpClass('NSArray')
-NSArchiver = objc.lookUpClass('NSArchiver')
-NSKeyedArchiver = objc.lookUpClass('NSKeyedArchiver')
-NSUnarchiver = objc.lookUpClass('NSUnarchiver')
-NSKeyedUnarchiver = objc.lookUpClass('NSKeyedUnarchiver')
-NSSet = objc.lookUpClass('NSSet')
+NSArray = objc.lookUpClass("NSArray")
+NSArchiver = objc.lookUpClass("NSArchiver")
+NSKeyedArchiver = objc.lookUpClass("NSKeyedArchiver")
+NSUnarchiver = objc.lookUpClass("NSUnarchiver")
+NSKeyedUnarchiver = objc.lookUpClass("NSKeyedUnarchiver")
+NSSet = objc.lookUpClass("NSSet")
 
-class TestNSKeyedArchivingInterop (TestCase):
+
+class TestNSKeyedArchivingInterop(TestCase):
     @classmethod
     def setUpClass(cls):
-        src = os.path.join(MYDIR, 'dump-nsarchive.m')
-        dst = cls.progpath = os.path.join(MYDIR, 'dump-nsarchive')
+        src = os.path.join(MYDIR, "dump-nsarchive.m")
+        dst = cls.progpath = os.path.join(MYDIR, "dump-nsarchive")
 
-        subprocess.check_call([
-            'cc', '-o', dst, src, '-framework', 'Foundation',
-            '-DPyObjC_BUILD_RELEASE=%02d%02d'%(tuple(map(int, platform.mac_ver()[0].split('.')[:2]))),
-        ])
+        subprocess.check_call(
+            [
+                "cc",
+                "-o",
+                dst,
+                src,
+                "-framework",
+                "Foundation",
+                "-DPyObjC_BUILD_RELEASE=%02d%02d"
+                % (tuple(map(int, platform.mac_ver()[0].split(".")[:2]))),
+            ]
+        )
 
     @classmethod
     def tearDownClass(cls):
@@ -49,10 +58,7 @@ class TestNSKeyedArchivingInterop (TestCase):
             os.unlink(cls.progpath)
 
     def test_interop_string(self):
-        for testval in (
-                    b'hello world'.decode('utf-8'),
-                    'goodbye moon',
-                ):
+        for testval in (b"hello world".decode("utf-8"), "goodbye moon"):
             v = NSArray.arrayWithObject_(testval)
             data = NSKeyedArchiver.archivedDataWithRootObject_(v)
 
@@ -60,17 +66,13 @@ class TestNSKeyedArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'keyed', fp.name])
+                converted = subprocess.check_output([self.progpath, "keyed", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
     def test_interop_float(self):
-        for testval in (
-                    -4.5,
-                    0,
-                    5.5e10,
-                ):
+        for testval in (-4.5, 0, 5.5e10):
             v = NSArray.arrayWithObject_(testval)
             data = NSKeyedArchiver.archivedDataWithRootObject_(v)
 
@@ -78,19 +80,13 @@ class TestNSKeyedArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'keyed', fp.name])
+                converted = subprocess.check_output([self.progpath, "keyed", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
     def test_interop_int(self):
-        for testval in (
-                    -42,
-                    0,
-                    42,
-                    -2**62,
-                    2**62
-                ):
+        for testval in (-42, 0, 42, -2 ** 62, 2 ** 62):
             v = NSArray.arrayWithObject_(testval)
             data = NSKeyedArchiver.archivedDataWithRootObject_(v)
 
@@ -98,12 +94,12 @@ class TestNSKeyedArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'keyed', fp.name])
+                converted = subprocess.check_output([self.progpath, "keyed", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
-        testval = 2**64
+        testval = 2 ** 64
         v = NSArray.arrayWithObject_(testval)
         data = NSKeyedArchiver.archivedDataWithRootObject_(v)
 
@@ -111,13 +107,15 @@ class TestNSKeyedArchivingInterop (TestCase):
             fp.write(data.bytes())
             fp.flush()
 
-            self.assertRaises(subprocess.CalledProcessError, subprocess.check_output, [self.progpath, 'keyed', fp.name])
+            self.assertRaises(
+                subprocess.CalledProcessError,
+                subprocess.check_output,
+                [self.progpath, "keyed", fp.name],
+            )
 
     @onlyPython3
     def test_interop_data(self):
-        for testval in (
-                    b'hello world',
-                ):
+        for testval in (b"hello world",):
             if sys.version_info[0] == 2:
                 testval = buffer(testval)
 
@@ -128,16 +126,13 @@ class TestNSKeyedArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'keyed', fp.name])
+                converted = subprocess.check_output([self.progpath, "keyed", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
     def test_interop_seq(self):
-        for testval in (
-                    ["a", "b", 3],
-                    ("a", "b", 3),
-                ):
+        for testval in (["a", "b", 3], ("a", "b", 3)):
 
             data = NSKeyedArchiver.archivedDataWithRootObject_(testval)
 
@@ -145,17 +140,14 @@ class TestNSKeyedArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'keyed', fp.name])
+                converted = subprocess.check_output([self.progpath, "keyed", fp.name])
 
             converted = loads(converted)
             self.assertIs(type(converted), list)
             self.assertEqual(converted, list(testval))
 
     def test_interop_set(self):
-        for testval in (
-                    {"a", "b", 3},
-                    frozenset({"a", "b", 3}),
-                ):
+        for testval in ({"a", "b", 3}, frozenset({"a", "b", 3})):
 
             data = NSKeyedArchiver.archivedDataWithRootObject_(testval)
 
@@ -163,19 +155,17 @@ class TestNSKeyedArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'keyed', fp.name])
+                converted = subprocess.check_output([self.progpath, "keyed", fp.name])
 
-            self.assertTrue(converted.startswith(b'{('))
-            self.assertTrue(converted.endswith(b')}\n'))
-            converted = b'{' + converted[2:-3] + b'}'
-            converted = eval(converted.decode('utf-8'), dict(a='a', b='b'))
+            self.assertTrue(converted.startswith(b"{("))
+            self.assertTrue(converted.endswith(b")}\n"))
+            converted = b"{" + converted[2:-3] + b"}"
+            converted = eval(converted.decode("utf-8"), dict(a="a", b="b"))
 
             self.assertEqual(converted, set(testval))
 
     def test_interop_dict(self):
-        for testval in (
-                    {'a': 'b', 'c': 42 },
-                ):
+        for testval in ({"a": "b", "c": 42},):
 
             data = NSKeyedArchiver.archivedDataWithRootObject_(testval)
 
@@ -183,21 +173,30 @@ class TestNSKeyedArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'keyed', fp.name])
+                converted = subprocess.check_output([self.progpath, "keyed", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, testval)
 
-class TestNSArchivingInterop (TestCase):
+
+class TestNSArchivingInterop(TestCase):
     @classmethod
     def setUpClass(cls):
-        src = os.path.join(MYDIR, 'dump-nsarchive.m')
-        dst = cls.progpath = os.path.join(MYDIR, 'dump-nsarchive')
+        src = os.path.join(MYDIR, "dump-nsarchive.m")
+        dst = cls.progpath = os.path.join(MYDIR, "dump-nsarchive")
 
-        subprocess.check_call([
-            'cc', '-o', dst, src, '-framework', 'Foundation',
-            '-DPyObjC_BUILD_RELEASE=%02d%02d'%(tuple(map(int, platform.mac_ver()[0].split('.')[:2]))),
-        ])
+        subprocess.check_call(
+            [
+                "cc",
+                "-o",
+                dst,
+                src,
+                "-framework",
+                "Foundation",
+                "-DPyObjC_BUILD_RELEASE=%02d%02d"
+                % (tuple(map(int, platform.mac_ver()[0].split(".")[:2]))),
+            ]
+        )
 
     @classmethod
     def tearDownClass(cls):
@@ -205,10 +204,7 @@ class TestNSArchivingInterop (TestCase):
             os.unlink(cls.progpath)
 
     def test_interop_string(self):
-        for testval in (
-                    b'hello world'.decode('utf-8'),
-                    'goodbye moon',
-                ):
+        for testval in (b"hello world".decode("utf-8"), "goodbye moon"):
             v = NSArray.arrayWithObject_(testval)
             data = NSArchiver.archivedDataWithRootObject_(v)
 
@@ -216,17 +212,13 @@ class TestNSArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'plain', fp.name])
+                converted = subprocess.check_output([self.progpath, "plain", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
     def test_interop_float(self):
-        for testval in (
-                    -4.5,
-                    0,
-                    5.5e10,
-                ):
+        for testval in (-4.5, 0, 5.5e10):
             v = NSArray.arrayWithObject_(testval)
             data = NSArchiver.archivedDataWithRootObject_(v)
 
@@ -234,19 +226,13 @@ class TestNSArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'plain', fp.name])
+                converted = subprocess.check_output([self.progpath, "plain", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
     def test_interop_int(self):
-        for testval in (
-                    -42,
-                    0,
-                    42,
-                    -2**62,
-                    2**62
-                ):
+        for testval in (-42, 0, 42, -2 ** 62, 2 ** 62):
             v = NSArray.arrayWithObject_(testval)
             data = NSArchiver.archivedDataWithRootObject_(v)
 
@@ -254,12 +240,12 @@ class TestNSArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'plain', fp.name])
+                converted = subprocess.check_output([self.progpath, "plain", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
-        testval = 2**64
+        testval = 2 ** 64
         v = NSArray.arrayWithObject_(testval)
         data = NSArchiver.archivedDataWithRootObject_(v)
 
@@ -267,13 +253,15 @@ class TestNSArchivingInterop (TestCase):
             fp.write(data.bytes())
             fp.flush()
 
-            self.assertRaises(subprocess.CalledProcessError, subprocess.check_output, [self.progpath, 'plain', fp.name])
+            self.assertRaises(
+                subprocess.CalledProcessError,
+                subprocess.check_output,
+                [self.progpath, "plain", fp.name],
+            )
 
     @onlyPython3
     def test_interop_data(self):
-        for testval in (
-                    b'hello world',
-                ):
+        for testval in (b"hello world",):
             if sys.version_info[0] == 2:
                 testval = buffer(testval)
 
@@ -284,16 +272,13 @@ class TestNSArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'plain', fp.name])
+                converted = subprocess.check_output([self.progpath, "plain", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, [testval])
 
     def test_interop_seq(self):
-        for testval in (
-                    ["a", "b", 3],
-                    ("a", "b", 3),
-                ):
+        for testval in (["a", "b", 3], ("a", "b", 3)):
 
             data = NSArchiver.archivedDataWithRootObject_(testval)
 
@@ -301,17 +286,14 @@ class TestNSArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'plain', fp.name])
+                converted = subprocess.check_output([self.progpath, "plain", fp.name])
 
             converted = loads(converted)
             self.assertIs(type(converted), list)
             self.assertEqual(converted, list(testval))
 
     def test_interop_set(self):
-        for testval in (
-                    {"a", "b", 3},
-                    frozenset({"a", "b", 3}),
-                ):
+        for testval in ({"a", "b", 3}, frozenset({"a", "b", 3})):
 
             data = NSArchiver.archivedDataWithRootObject_(testval)
 
@@ -319,18 +301,16 @@ class TestNSArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'plain', fp.name])
+                converted = subprocess.check_output([self.progpath, "plain", fp.name])
 
-            self.assertTrue(converted.startswith(b'{('))
-            self.assertTrue(converted.endswith(b')}\n'))
-            converted = b'{' + converted[2:-3] + b'}'
-            converted = eval(converted.decode('utf-8'), dict(a='a', b='b'))
+            self.assertTrue(converted.startswith(b"{("))
+            self.assertTrue(converted.endswith(b")}\n"))
+            converted = b"{" + converted[2:-3] + b"}"
+            converted = eval(converted.decode("utf-8"), dict(a="a", b="b"))
             self.assertEqual(converted, set(testval))
 
     def test_interop_dict(self):
-        for testval in (
-                    {'a': 'b', 'c': 42 },
-                ):
+        for testval in ({"a": "b", "c": 42},):
 
             data = NSArchiver.archivedDataWithRootObject_(testval)
 
@@ -338,7 +318,7 @@ class TestNSArchivingInterop (TestCase):
                 fp.write(data.bytes())
                 fp.flush()
 
-                converted = subprocess.check_output([self.progpath, 'plain', fp.name])
+                converted = subprocess.check_output([self.progpath, "plain", fp.name])
 
             converted = loads(converted)
             self.assertEqual(converted, testval)
@@ -347,9 +327,11 @@ class TestNSArchivingInterop (TestCase):
 class Class1:
     pass
 
-class Class2 (object):
+
+class Class2(object):
     pass
 
+
 class Class3:
     def __init__(self):
         self.a = None
@@ -361,16 +343,17 @@ class Class3:
     def __setstate__(self, state):
         self.a, self.b = state
 
+
 class Class4:
     def __init__(self):
         self.a = None
         self.b = None
 
     def __getstate__(self):
-        return {'a': self.a, 'b': self.b, NSString.stringWithString_('c'): self.c}
+        return {"a": self.a, "b": self.b, NSString.stringWithString_("c"): self.c}
 
 
-class TestLoadingOlderVersions (TestCase):
+class TestLoadingOlderVersions(TestCase):
     def do_verify(self, path):
         import __main__
 
@@ -380,14 +363,14 @@ class TestLoadingOlderVersions (TestCase):
         __main__.Class3 = Class3
         __main__.Class4 = Class4
 
-        if path.endswith('keyed'):
+        if path.endswith("keyed"):
             archiver = NSKeyedUnarchiver
         else:
             archiver = NSUnarchiver
 
         data = archiver.unarchiveObjectWithFile_(path)
         self.assertIsInstance(data, Class2)
-        self.assertEqual(data.lst, [1,2,3])
+        self.assertEqual(data.lst, [1, 2, 3])
         self.assertEqual(data.string, "hello world")
         self.assertIsInstance(data.obj, Class1)
         o = data.obj
@@ -399,14 +382,15 @@ class TestLoadingOlderVersions (TestCase):
         self.assertEqual(o.a, 42)
         self.assertEqual(o.b, 21)
         o = data.o4
-        self.assertEqual(o.a, 'A')
-        self.assertEqual(o.b, 'B')
+        self.assertEqual(o.a, "A")
+        self.assertEqual(o.b, "B")
 
+    for fname in os.listdir(os.path.join(MYDIR, "archives")):
 
-    for fname in os.listdir(os.path.join(MYDIR, 'archives')):
         def test(self, fname=fname):
-            self.do_verify(os.path.join(MYDIR, 'archives', fname))
-        locals()['test_%s'%(fname.replace('.', '_').replace('-', '_'))] = test
+            self.do_verify(os.path.join(MYDIR, "archives", fname))
+
+        locals()["test_%s" % (fname.replace(".", "_").replace("-", "_"))] = test
         del test
 
 
