@@ -7,15 +7,16 @@ import operator
 # Import some of the stdlib tests
 from test import mapping_tests
 
-NSArray = objc.lookUpClass('NSArray')
-NSMutableArray = objc.lookUpClass('NSMutableArray')
+NSArray = objc.lookUpClass("NSArray")
+NSMutableArray = objc.lookUpClass("NSMutableArray")
 
-class ArrayTests (seq_tests.CommonTest):
+
+class ArrayTests(seq_tests.CommonTest):
     type2test = NSArray
 
     def test_from_iterator(self):
         a = NSArray(i for i in range(5))
-        self.assertEqual(a, NSArray([0,1,2,3,4]))
+        self.assertEqual(a, NSArray([0, 1, 2, 3, 4]))
 
     def test_pyobjc_copy(self):
         a = NSArray()
@@ -33,7 +34,6 @@ class ArrayTests (seq_tests.CommonTest):
         self.assertEqual(a, b)
         self.assertIsInstance(b, NSArray)
 
-
     @onlyIf(0, "Not relevant for NSArray")
     def test_pickle(self):
         pass
@@ -75,7 +75,7 @@ class ArrayTests (seq_tests.CommonTest):
         self.assertRaises(ValueError, u.index, 2)
 
         u = self.type2test([-2, -1, 0, 0, 1, 2])
-        #self.assertEqual(u.count(0), 2)
+        # self.assertEqual(u.count(0), 2)
         self.assertEqual(u.index(0), 2)
         self.assertEqual(u.index(0, 2), 2)
         self.assertEqual(u.index(-2, -10), 0)
@@ -85,7 +85,6 @@ class ArrayTests (seq_tests.CommonTest):
 
         self.assertRaises(TypeError, u.index)
 
-
     def test_addmul(self):
         # Same as the one in our superclass, but disables subclassing tests
         u1 = self.type2test([0])
@@ -94,26 +93,29 @@ class ArrayTests (seq_tests.CommonTest):
         self.assertEqual(u1, self.type2test() + u1)
         self.assertEqual(u1 + self.type2test([1]), u2)
         self.assertEqual(self.type2test([-1]) + u1, self.type2test([-1, 0]))
-        self.assertEqual(self.type2test(), u2*0)
-        self.assertEqual(self.type2test(), 0*u2)
-        self.assertEqual(self.type2test(), u2*0)
-        self.assertEqual(self.type2test(), 0*u2)
-        self.assertEqual(u2, u2*1)
-        self.assertEqual(u2, 1*u2)
-        self.assertEqual(u2, u2*1)
-        self.assertEqual(u2, 1*u2)
-        self.assertEqual(u2+u2, u2*2)
-        self.assertEqual(u2+u2, 2*u2)
-        self.assertEqual(u2+u2, u2*2)
-        self.assertEqual(u2+u2, 2*u2)
-        self.assertEqual(u2+u2+u2, u2*3)
-        self.assertEqual(u2+u2+u2, 3*u2)
-
+        self.assertEqual(self.type2test(), u2 * 0)
+        self.assertEqual(self.type2test(), 0 * u2)
+        self.assertEqual(self.type2test(), u2 * 0)
+        self.assertEqual(self.type2test(), 0 * u2)
+        self.assertEqual(u2, u2 * 1)
+        self.assertEqual(u2, 1 * u2)
+        self.assertEqual(u2, u2 * 1)
+        self.assertEqual(u2, 1 * u2)
+        self.assertEqual(u2 + u2, u2 * 2)
+        self.assertEqual(u2 + u2, 2 * u2)
+        self.assertEqual(u2 + u2, u2 * 2)
+        self.assertEqual(u2 + u2, 2 * u2)
+        self.assertEqual(u2 + u2 + u2, u2 * 3)
+        self.assertEqual(u2 + u2 + u2, 3 * u2)
 
     # Disable a couple of tests that are not relevant for us.
 
-    def test_bigrepeat(self): pass
-    def test_getitemoverwriteiter(self): pass
+    def test_bigrepeat(self):
+        pass
+
+    def test_getitemoverwriteiter(self):
+        pass
+
     def test_contains_fake(self):
         # Disabled because the test seems to make use of an
         # implementation detail of sequences, it assumes
@@ -128,6 +130,7 @@ class ArrayTests (seq_tests.CommonTest):
         # different order: 'if value == X', which causes
         # this test to fail.
         pass
+
     def test_contains_order(self):
         # See test_contains_fake
         pass
@@ -136,7 +139,8 @@ class ArrayTests (seq_tests.CommonTest):
     def test_free_after_iterating(self):
         pass
 
-class MutableArrayTest (list_tests.CommonTest):
+
+class MutableArrayTest(list_tests.CommonTest):
     type2test = NSMutableArray
 
     @onlyIf(0, "test irrelevant for NSMutableArray")
@@ -160,93 +164,88 @@ class MutableArrayTest (list_tests.CommonTest):
         pass
 
     def test_pyobjc_setitem(self):
-        l = [1,2,3,4,5,6,7,8,9]
-        a = NSMutableArray([1,2,3,4,5,6,7,8,9])
-        self.assertRaises(TypeError, operator.setitem, a, 'a', 'b')
-        self.assertRaises(ValueError, operator.setitem, a, slice(1,4,0), ('c', 'd'))
+        l = [1, 2, 3, 4, 5, 6, 7, 8, 9]
+        a = NSMutableArray([1, 2, 3, 4, 5, 6, 7, 8, 9])
+        self.assertRaises(TypeError, operator.setitem, a, "a", "b")
+        self.assertRaises(ValueError, operator.setitem, a, slice(1, 4, 0), ("c", "d"))
         a[1:4] = a
         l[1:4] = l
         self.assertEqual(a, NSMutableArray(l))
 
-        l = [1,2,3,4]
-        a = NSMutableArray([1,2,3,4])
-        l[-2:2] = 'a'
-        a[-2:2] = 'a'
+        l = [1, 2, 3, 4]
+        a = NSMutableArray([1, 2, 3, 4])
+        l[-2:2] = "a"
+        a[-2:2] = "a"
         self.assertEqual(a, NSMutableArray(l))
 
-        l = [1,2,3,4]
-        a = NSMutableArray([1,2,3,4])
-        self.assertRaises(ValueError, operator.setitem, a, slice(None, None,2), a)
-        self.assertRaises(ValueError, operator.setitem, a, slice(None, None,2), l)
+        l = [1, 2, 3, 4]
+        a = NSMutableArray([1, 2, 3, 4])
+        self.assertRaises(ValueError, operator.setitem, a, slice(None, None, 2), a)
+        self.assertRaises(ValueError, operator.setitem, a, slice(None, None, 2), l)
 
     def test_pyobjc_clear(self):
-        a = NSMutableArray([1,2,3])
+        a = NSMutableArray([1, 2, 3])
         self.assertEqual(len(a), 3)
 
         a.clear()
         self.assertEqual(len(a), 0)
 
     def test_pyobjc_radd(self):
-        a = NSArray([1,2])
+        a = NSArray([1, 2])
 
-        res = a + [3,4]
-        self.assertEqual(res, NSArray([1,2,3,4]))
+        res = a + [3, 4]
+        self.assertEqual(res, NSArray([1, 2, 3, 4]))
         self.assertIsInstance(res, NSArray)
 
-        res = a + (3,4)
-        self.assertEqual(res, NSArray([1,2,3,4]))
+        res = a + (3, 4)
+        self.assertEqual(res, NSArray([1, 2, 3, 4]))
         self.assertIsInstance(res, NSArray)
 
-        res = a + (x for x in (3,4))
-        self.assertEqual(res, NSArray([1,2,3,4]))
+        res = a + (x for x in (3, 4))
+        self.assertEqual(res, NSArray([1, 2, 3, 4]))
         self.assertIsInstance(res, NSArray)
 
-        res = [3,4] + a
-        self.assertEqual(res, NSArray([3,4, 1, 2]))
+        res = [3, 4] + a
+        self.assertEqual(res, NSArray([3, 4, 1, 2]))
         self.assertIsInstance(res, NSArray)
 
-        res = (3,4) + a
-        self.assertEqual(res, NSArray([3,4, 1, 2]))
+        res = (3, 4) + a
+        self.assertEqual(res, NSArray([3, 4, 1, 2]))
         self.assertIsInstance(res, NSArray)
 
-        res = (x for x in (3,4)) + a
-        self.assertEqual(res, NSArray([3,4, 1, 2]))
+        res = (x for x in (3, 4)) + a
+        self.assertEqual(res, NSArray([3, 4, 1, 2]))
         self.assertIsInstance(res, NSArray)
 
-
     def test_pyobjc_insert(self):
-        u = self.type2test([1,2,3,4,])
+        u = self.type2test([1, 2, 3, 4])
         u.insert(-8, 0)
 
-        v = self.type2test([0, 1,2,3,4,])
+        v = self.type2test([0, 1, 2, 3, 4])
         self.assertEqual(u, v)
 
-        u = self.type2test([1,2,3,4,])
+        u = self.type2test([1, 2, 3, 4])
         u.insert(-2, 0)
-        v = self.type2test([1,2,0, 3,4,])
+        v = self.type2test([1, 2, 0, 3, 4])
         self.assertEqual(u, v)
 
     def test_pyobjc_pop(self):
-        u = self.type2test([1,2,3,4,])
+        u = self.type2test([1, 2, 3, 4])
         self.assertRaises(IndexError, u.pop, -8)
 
-        u = self.type2test([1,2,3,4,])
+        u = self.type2test([1, 2, 3, 4])
         self.assertEqual(u.pop(-2), 3)
 
-
     def test_pyobjc_delitem(self):
-        u = self.type2test([1,2,3,4,])
+        u = self.type2test([1, 2, 3, 4])
         del u[3:1]
 
-        v = self.type2test([1,2,3,4,])
+        v = self.type2test([1, 2, 3, 4])
         self.assertEqual(u, v)
 
-
-
     def test_init(self):
         # Removed tests that are not relevant
 
-
         # Iterable arg is optional
         self.assertEqual(self.type2test([]), self.type2test())
 
@@ -277,7 +276,7 @@ class MutableArrayTest (list_tests.CommonTest):
         self.assertRaises(ValueError, u.index, 2)
 
         u = self.type2test([-2, -1, 0, 0, 1, 2])
-        #self.assertEqual(u.count(0), 2)
+        # self.assertEqual(u.count(0), 2)
         self.assertEqual(u.index(0), 2)
         self.assertEqual(u.index(0, 2), 2)
         self.assertEqual(u.index(-2, -10), 0)
@@ -287,7 +286,6 @@ class MutableArrayTest (list_tests.CommonTest):
 
         self.assertRaises(TypeError, u.index)
 
-
         if 0:
             # Disabled due to dependency on the
             # order of arguments in the '==' expression
@@ -313,8 +311,8 @@ class MutableArrayTest (list_tests.CommonTest):
         self.assertEqual(a.index(0, -3), 3)
         self.assertEqual(a.index(0, 3, 4), 3)
         self.assertEqual(a.index(0, -3, -2), 3)
-        self.assertEqual(a.index(0, -4*sys.maxsize, 4*sys.maxsize), 2)
-        self.assertRaises(ValueError, a.index, 0, 4*sys.maxsize,-4*sys.maxsize)
+        self.assertEqual(a.index(0, -4 * sys.maxsize, 4 * sys.maxsize), 2)
+        self.assertRaises(ValueError, a.index, 0, 4 * sys.maxsize, -4 * sys.maxsize)
         self.assertRaises(ValueError, a.index, 2, 0, -10)
         a.remove(0)
         self.assertRaises(ValueError, a.index, 2, 0, 4)
@@ -326,9 +324,11 @@ class MutableArrayTest (list_tests.CommonTest):
             class EvilCmp:
                 def __init__(self, victim):
                     self.victim = victim
+
                 def __eq__(self, other):
                     del self.victim[:]
-                return False
+                    return False
+
             a = self.type2test()
             a[:] = [EvilCmp(a) for _ in range(100)]
             # This used to seg fault before patch #1005778
@@ -350,69 +350,78 @@ class MutableArrayTest (list_tests.CommonTest):
 
         self.assertRaises(TypeError, a.remove)
 
-        d = self.type2test('abcdefghcij')
-        d.remove('c')
-        self.assertEqual(d, self.type2test('abdefghcij'))
-        d.remove('c')
-        self.assertEqual(d, self.type2test('abdefghij'))
-        self.assertRaises(ValueError, d.remove, 'c')
-        self.assertEqual(d, self.type2test('abdefghij'))
-
-
-
+        d = self.type2test("abcdefghcij")
+        d.remove("c")
+        self.assertEqual(d, self.type2test("abdefghcij"))
+        d.remove("c")
+        self.assertEqual(d, self.type2test("abdefghij"))
+        self.assertRaises(ValueError, d.remove, "c")
+        self.assertEqual(d, self.type2test("abdefghij"))
 
     # Disable a couple of tests that are not relevant for us.
-    def test_bigrepeat(self): pass
-    def test_repr(self): pass
-    def test_contains_fake(self): pass
-    def test_print(self): pass
-    def test_contains_order(self): pass
-    def test_getitemoverwriteiter(self): pass
+    def test_bigrepeat(self):
+        pass
+
+    def test_repr(self):
+        pass
+
+    def test_contains_fake(self):
+        pass
+
+    def test_print(self):
+        pass
+
+    def test_contains_order(self):
+        pass
+
+    def test_getitemoverwriteiter(self):
+        pass
 
     # Disable inplace operation tests ( += and *= ) because
     # we cannot support true inplace operations: most NSArray
     # and NSMutable array instances are actually instances of
     # NSCFArray and we cannot (and shouldn't detect whether or
     # not a value is mutable)
-    def test_imul(self): pass
-    def test_iadd(self): pass
+    def test_imul(self):
+        pass
 
+    def test_iadd(self):
+        pass
 
     def test_count(self):
         # Disabled because NSArray.count has a different
         # interface than list.count
         pass
 
-
     def test_sort(self):
-        base = [2,1,5,4,1,3]
+        base = [2, 1, 5, 4, 1, 3]
 
         l = self.type2test(base)
         l.sort()
-        self.assertEqual(l, self.type2test([1,1,2,3,4,5]))
+        self.assertEqual(l, self.type2test([1, 1, 2, 3, 4, 5]))
 
         l = self.type2test(base)
         l.sort(reverse=True)
-        self.assertEqual(l, self.type2test([5,4,3,2,1,1]))
+        self.assertEqual(l, self.type2test([5, 4, 3, 2, 1, 1]))
 
-        base = [-2,1,-5,4,3]
+        base = [-2, 1, -5, 4, 3]
         l = self.type2test(base)
-        l.sort(key=lambda x:abs(x))
-        self.assertEqual(l, self.type2test([1,-2,3,4,-5]))
+        l.sort(key=lambda x: abs(x))
+        self.assertEqual(l, self.type2test([1, -2, 3, 4, -5]))
 
         l = self.type2test(base)
-        l.sort(key=lambda x:abs(x), reverse=True)
-        self.assertEqual(l, self.type2test([-5,4,3,-2,1]))
+        l.sort(key=lambda x: abs(x), reverse=True)
+        self.assertEqual(l, self.type2test([-5, 4, 3, -2, 1]))
 
         if sys.version_info[0] == 2:
-            base = [-2,1,-5,4,3]
+            base = [-2, 1, -5, 4, 3]
             l = self.type2test(base)
             l.sort(cmp=lambda x, y: cmp(abs(x), abs(y)))
-            self.assertEqual(l, self.type2test([1,-2,3,4,-5]))
+            self.assertEqual(l, self.type2test([1, -2, 3, 4, -5]))
 
             l = self.type2test(base)
             l.sort(cmp=lambda x, y: cmp(abs(x), abs(y)), reverse=True)
-            self.assertEqual(l, self.type2test([-5,4,3,-2,1]))
+            self.assertEqual(l, self.type2test([-5, 4, 3, -2, 1]))
 
 
 if __name__ == "__main__":
