@@ -5,10 +5,12 @@ import operator
 import sys
 
 from PyObjCTest.sequence import *
-objc.addConvenienceForBasicSequence('OC_TestSequence', False)
-objc.addConvenienceForBasicSequence('OC_TestMutableSequence', True)
 
-class OC_WithHash (objc.lookUpClass('NSObject')):
+objc.addConvenienceForBasicSequence("OC_TestSequence", False)
+objc.addConvenienceForBasicSequence("OC_TestMutableSequence", True)
+
+
+class OC_WithHash(objc.lookUpClass("NSObject")):
     def initWithHash_(self, value):
         self = objc.super(OC_WithHash, self).init()
         if self is None:
@@ -21,14 +23,16 @@ class OC_WithHash (objc.lookUpClass('NSObject')):
         return self._hash
 
     def someKey(self):
-        objc.lookUpClass('NSException').alloc().initWithName_reason_userInfo_(
-            'NSRangeException', 'Test exception', {}).raise__()
+        objc.lookUpClass("NSException").alloc().initWithName_reason_userInfo_(
+            "NSRangeException", "Test exception", {}
+        ).raise__()
         return 1
 
     def someOtherKey(self):
         raise KeyError()
 
-class OC_Compared (objc.lookUpClass('NSObject')):
+
+class OC_Compared(objc.lookUpClass("NSObject")):
     def initWithValue_(self, value):
         self = super(OC_Compared, self).init()
         if self is None:
@@ -60,9 +64,9 @@ class OC_Compared (objc.lookUpClass('NSObject')):
             return 0
 
 
-class TestBasicConvenience (TestCase):
+class TestBasicConvenience(TestCase):
     def test_hashprotocol(self):
-        v = objc.lookUpClass('NSObject').alloc().init()
+        v = objc.lookUpClass("NSObject").alloc().init()
         v.hash()
 
         hash(v) + 0
@@ -73,13 +77,13 @@ class TestBasicConvenience (TestCase):
         self.assertEqual(hash(v), -2)
 
     def test_hash_not_enormous(self):
-        v = OC_WithHash.alloc().initWithHash_(2**64-1)
-        self.assertEqual(v.hash(), 2**64-1)
-        self.assertTrue(-sys.maxsize-1 <= hash(v) <= sys.maxsize )
+        v = OC_WithHash.alloc().initWithHash_(2 ** 64 - 1)
+        self.assertEqual(v.hash(), 2 ** 64 - 1)
+        self.assertTrue(-sys.maxsize - 1 <= hash(v) <= sys.maxsize)
 
     def test_comparisons(self):
-        o1 = objc.lookUpClass('NSObject').alloc().init()
-        o2 = objc.lookUpClass('NSObject').alloc().init()
+        o1 = objc.lookUpClass("NSObject").alloc().init()
+        o2 = objc.lookUpClass("NSObject").alloc().init()
 
         self.assertTrue(o1 == o1)
         self.assertFalse(o1 == o2)
@@ -111,8 +115,8 @@ class TestBasicConvenience (TestCase):
             self.assertEqual(cmp(o2, o3), 0)
             self.assertEqual(cmp(o2, o1), 1)
 
-            first = objc.lookUpClass('NSObject').alloc().init()
-            second = objc.lookUpClass('NSObject').alloc().init()
+            first = objc.lookUpClass("NSObject").alloc().init()
+            second = objc.lookUpClass("NSObject").alloc().init()
 
             # '__cmp__' returns NotImplemented, what happens
             # next is not really interesting (but this shoudn't
@@ -121,9 +125,10 @@ class TestBasicConvenience (TestCase):
             b = cmp(first, second)
             self.assertEqual(a, b)
 
-class TestNSDecimalNumber (TestCase):
+
+class TestNSDecimalNumber(TestCase):
     def setUp(self):
-        self.NSDecimalNumber = objc.lookUpClass('NSDecimalNumber')
+        self.NSDecimalNumber = objc.lookUpClass("NSDecimalNumber")
 
     def testCreation(self):
         v = self.NSDecimalNumber()
@@ -251,20 +256,20 @@ class TestNSDecimalNumber (TestCase):
         self.assertRaises(TypeError, operator.mod, 2, b_o)
         self.assertRaises(TypeError, operator.mod, 2, b_c)
 
-        #v_o = a_o % b_o
-        #v_c = a_c % b_c
-        #self.assertEqual(str(v_o), str(v_c))
-        #self.assertIsInstance(v_o, self.NSDecimalNumber)
+        # v_o = a_o % b_o
+        # v_c = a_c % b_c
+        # self.assertEqual(str(v_o), str(v_c))
+        # self.assertIsInstance(v_o, self.NSDecimalNumber)
 
-        #v_o = 2 % b_o
-        #v_c = 2 % b_c
-        #self.assertEqual(str(v_o), str(v_c))
-        #self.assertIsInstance(v_o, self.NSDecimalNumber)
+        # v_o = 2 % b_o
+        # v_c = 2 % b_c
+        # self.assertEqual(str(v_o), str(v_c))
+        # self.assertIsInstance(v_o, self.NSDecimalNumber)
 
-        #v_o = a_o % 2
-        #v_c = a_c % 2
+        # v_o = a_o % 2
+        # v_c = a_c % 2
         self.assertEqual(str(v_o), str(v_c))
-        #self.assertIsInstance(v_o, self.NSDecimalNumber)
+        # self.assertIsInstance(v_o, self.NSDecimalNumber)
 
         # Negate
         v_o = -a_o
@@ -325,38 +330,39 @@ class TestNSDecimalNumber (TestCase):
         self.assertTrue(b_o >= a_o)
 
         self.assertTrue(b_o == c_o)
-        self.assertTrue(b_o == objc.NSDecimal('2.5'))
+        self.assertTrue(b_o == objc.NSDecimal("2.5"))
         self.assertFalse(b_o == a_o)
 
         self.assertTrue(b_o != a_o)
         self.assertFalse(b_o != c_o)
 
-class TestNSData (TestCase):
+
+class TestNSData(TestCase):
     def test_creation(self):
-        NSData = objc.lookUpClass('NSData')
-        NSMutableData = objc.lookUpClass('NSMutableData')
+        NSData = objc.lookUpClass("NSData")
+        NSMutableData = objc.lookUpClass("NSMutableData")
 
-        data = NSData(b'hello')
-        data2 = NSMutableData(b'moon')
+        data = NSData(b"hello")
+        data2 = NSMutableData(b"moon")
 
-        self.assertEqual(bytes(data), b'hello')
-        self.assertEqual(bytes(data2), b'moon')
+        self.assertEqual(bytes(data), b"hello")
+        self.assertEqual(bytes(data2), b"moon")
 
         self.assertIsInstance(data, NSData)
         self.assertIsInstance(data2, NSMutableData)
 
     def test_to_string(self):
-        NSData = objc.lookUpClass('NSData')
+        NSData = objc.lookUpClass("NSData")
 
-        data = NSData(b'hello')
+        data = NSData(b"hello")
         data2 = NSData()
 
-        self.assertEqual(str(data), str(b'hello'))
-        self.assertEqual(str(data2), str(b''))
+        self.assertEqual(str(data), str(b"hello"))
+        self.assertEqual(str(data2), str(b""))
 
     def reading(self):
-        NSData = objc.lookUpClass('NSData')
-        bdata = b'hello'
+        NSData = objc.lookUpClass("NSData")
+        bdata = b"hello"
         data = NSData(bdata)
 
         self.assertEqual(data[0], bdata[0])
@@ -364,115 +370,117 @@ class TestNSData (TestCase):
         self.assertEqual(data[0:6:2], bdata[0:6:2])
 
     def writing(self):
-        NSData = objc.lookUpClass('NSMutableData')
-        bdata = b'hello'
+        NSData = objc.lookUpClass("NSMutableData")
+        bdata = b"hello"
         data = NSData(bdata)
         barray = bytearray(bdata)
 
-        bdata[0] = b'x'[0]
-        barray[0] = b'x'[0]
+        bdata[0] = b"x"[0]
+        barray[0] = b"x"[0]
         self.assertEqual(bytes(bdata), bytes(barray))
 
-        bdata[0:2] = b'..'
-        barray[0:2] = b'..'
+        bdata[0:2] = b".."
+        barray[0:2] = b".."
         self.assertEqual(bytes(bdata), bytes(barray))
 
-        bdata[0:4:2] = b'++'
-        barray[0:4:2] = b'++'
+        bdata[0:4:2] = b"++"
+        barray[0:4:2] = b"++"
         self.assertEqual(bytes(bdata), bytes(barray))
 
         for idx in range(len(barray)):
             self.assertEqual(barray[idx], bdata[idx])
 
         try:
-            barray[0:4:2] = b'----'
+            barray[0:4:2] = b"----"
             self.fail("Exception not raised")
         except ValueError:
             pass
 
         try:
-            bdata[0:4:2] = b'----'
+            bdata[0:4:2] = b"----"
             self.fail("Exception not raised")
         except ValueError:
             pass
 
         # XXX: more testing needed?
 
+
 class TestNULLConvenience(TestCase):
     def test_nsnull(self):
-        NSNull = objc.lookUpClass('NSNull')
+        NSNull = objc.lookUpClass("NSNull")
         null = NSNull.null()
         self.assertFalse(null)
 
-class TestNSString (TestCase):
-    def test_nsstring_creation(self):
-        NSString = objc.lookUpClass('NSString')
 
-        value = NSString('hello world')
+class TestNSString(TestCase):
+    def test_nsstring_creation(self):
+        NSString = objc.lookUpClass("NSString")
+
+        value = NSString("hello world")
         self.assertIsInstance(value, objc.pyobjc_unicode)
-        self.assertEqual(value, 'hello world')
+        self.assertEqual(value, "hello world")
         self.assertIsInstance(value.nsstring(), NSString)
 
         value = NSString()
         self.assertIsInstance(value, objc.pyobjc_unicode)
-        self.assertEqual(value, '')
+        self.assertEqual(value, "")
         self.assertIsInstance(value.nsstring(), NSString)
 
     def test_nsstring_creation(self):
-        NSMutableString = objc.lookUpClass('NSMutableString')
+        NSMutableString = objc.lookUpClass("NSMutableString")
 
-        value = NSMutableString('hello world')
+        value = NSMutableString("hello world")
         self.assertIsInstance(value, objc.pyobjc_unicode)
-        self.assertEqual(value, 'hello world')
+        self.assertEqual(value, "hello world")
         self.assertIsInstance(value.nsstring(), NSMutableString)
 
         value = NSMutableString()
         self.assertIsInstance(value, objc.pyobjc_unicode)
-        self.assertEqual(value, '')
+        self.assertEqual(value, "")
         self.assertIsInstance(value.nsstring(), NSMutableString)
 
     def test_apis(self):
-        NSMutableString = objc.lookUpClass('NSMutableString')
+        NSMutableString = objc.lookUpClass("NSMutableString")
 
-        value = NSMutableString('hello world')
+        value = NSMutableString("hello world")
         self.assertIsNotInstance(value, NSMutableString)
         value = value.nsstring()
         self.assertIsInstance(value, NSMutableString)
 
         self.assertEqual(len(value), 11)
-        self.assertFalse(value.startswith('Hello'))
-        self.assertTrue(value.startswith('hello'))
-        self.assertFalse(value.endswith('moon'))
-        self.assertTrue(value.endswith('orld'))
+        self.assertFalse(value.startswith("Hello"))
+        self.assertTrue(value.startswith("hello"))
+        self.assertFalse(value.endswith("moon"))
+        self.assertTrue(value.endswith("orld"))
 
-class TestConvenienceHelpers (TestCase):
+
+class TestConvenienceHelpers(TestCase):
     def test_add_for_class(self):
         self.assertNotIn("MyObject", convenience.CLASS_METHODS)
 
-        methods = [
-            ('info', lambda self: self.description())
-        ]
+        methods = [("info", lambda self: self.description())]
 
         try:
             objc.addConvenienceForClass("MyObject", methods)
             self.assertEqual(convenience.CLASS_METHODS["MyObject"], tuple(methods))
 
         finally:
-            if 'MyObject' in convenience.CLASS_METHODS:
+            if "MyObject" in convenience.CLASS_METHODS:
                 del convenience.CLASS_METHODS["MyObject"]
 
 
-
-class TestBasicConveniences (TestCase):
+class TestBasicConveniences(TestCase):
     def testBundleForClass(self):
         orig = convenience.currentBundle
         try:
             the_bundle = object()
+
             def currentBundle():
                 return the_bundle
+
             convenience.currentBundle = currentBundle
 
-            class OC_Test_Basic_Convenience_1 (objc.lookUpClass("NSObject")):
+            class OC_Test_Basic_Convenience_1(objc.lookUpClass("NSObject")):
                 pass
 
             self.assertIs(OC_Test_Basic_Convenience_1.bundleForClass(), the_bundle)
@@ -480,70 +488,71 @@ class TestBasicConveniences (TestCase):
             convenience.currentBundle = orig
 
     def test_kvc_helper(self):
-        o = objc.lookUpClass('NSURL').URLWithString_('http://www.python.org/')
-        self.assertEqual(o.host(), 'www.python.org')
+        o = objc.lookUpClass("NSURL").URLWithString_("http://www.python.org/")
+        self.assertEqual(o.host(), "www.python.org")
 
-        self.assertEqual(o._.host, 'www.python.org')
-        self.assertEqual(o._['host'], 'www.python.org')
+        self.assertEqual(o._.host, "www.python.org")
+        self.assertEqual(o._["host"], "www.python.org")
         self.assertRaises(TypeError, lambda: o._[42])
-        self.assertEqual(repr(o._), '<KVC accessor for %r>'%(o,))
-        self.assertRaises(AttributeError, getattr, o._, 'nosuchattr')
-        self.assertRaises(AttributeError, getattr, o._, '')
+        self.assertEqual(repr(o._), "<KVC accessor for %r>" % (o,))
+        self.assertRaises(AttributeError, getattr, o._, "nosuchattr")
+        self.assertRaises(AttributeError, getattr, o._, "")
         self.assertRaises(TypeError, o._.__getitem__, 42)
 
-        o = objc.lookUpClass('NSMutableDictionary').dictionary()
+        o = objc.lookUpClass("NSMutableDictionary").dictionary()
         o._.key1 = 1
-        o._['key2'] = 2
+        o._["key2"] = 2
 
-        self.assertEqual(o, {'key1': 1, 'key2': 2 })
+        self.assertEqual(o, {"key1": 1, "key2": 2})
 
         # At least on OSX 10.11 the KVC accessor for NSDictionary returns
         # nil for non-existing keys.
-        #self.assertRaises(AttributeError, getattr, o._, 'nosuchattr')
+        # self.assertRaises(AttributeError, getattr, o._, 'nosuchattr')
         self.assertRaises(TypeError, o._.__setitem__, 42, 1)
 
         o = OC_WithHash.alloc().initWithHash_(1)
-        self.assertRaises(IndexError, getattr, o._, 'someKey')
-        self.assertRaises(KeyError, getattr, o._, 'someOtherKey')
+        self.assertRaises(IndexError, getattr, o._, "someKey")
+        self.assertRaises(KeyError, getattr, o._, "someOtherKey")
 
 
-class TestSequences (TestCase):
+class TestSequences(TestCase):
     def test_reading(self):
-        o = OC_TestSequence.alloc().initWithArray_(['a', 'b', 'c', 'd'])
+        o = OC_TestSequence.alloc().initWithArray_(["a", "b", "c", "d"])
 
         self.assertEqual(len(o), 4)
-        self.assertEqual(o[0], 'a')
-        self.assertEqual(o[3], 'd')
-        self.assertEqual(o[-1], 'd')
-        self.assertEqual(o[-3], 'b')
+        self.assertEqual(o[0], "a")
+        self.assertEqual(o[3], "d")
+        self.assertEqual(o[-1], "d")
+        self.assertEqual(o[-3], "b")
 
         self.assertRaises(IndexError, operator.getitem, o, 6)
         self.assertRaises(IndexError, operator.getitem, o, -6)
         self.assertRaises(ValueError, operator.getitem, o, slice(1, 3))
 
-        self.assertEqual(list(iter(o)), ['a', 'b', 'c', 'd'])
-        self.assertRaises(AttributeError, operator.setitem, o, 1, 'A')
+        self.assertEqual(list(iter(o)), ["a", "b", "c", "d"])
+        self.assertRaises(AttributeError, operator.setitem, o, 1, "A")
 
         o = OC_TestSequence.alloc().initWithArray_([])
         self.assertEqual(list(iter(o)), [])
 
     def test_writing(self):
-        o = OC_TestMutableSequence.alloc().initWithArray_(['a', 'b', 'c', 'd'])
+        o = OC_TestMutableSequence.alloc().initWithArray_(["a", "b", "c", "d"])
 
-        o[0] = 'A'
-        self.assertEqual(o[0], 'A')
+        o[0] = "A"
+        self.assertEqual(o[0], "A")
 
-        o[2] = 'C'
-        self.assertEqual(o[2], 'C')
+        o[2] = "C"
+        self.assertEqual(o[2], "C")
 
-        o[-3] = 'X'
-        self.assertEqual(o[1], 'X')
+        o[-3] = "X"
+        self.assertEqual(o[1], "X")
 
-        self.assertEqual(list(o), ['A', 'X', 'C', 'd'])
+        self.assertEqual(list(o), ["A", "X", "C", "d"])
+
+        self.assertRaises(IndexError, operator.setitem, o, 6, "x")
+        self.assertRaises(IndexError, operator.setitem, o, -7, "x")
+        self.assertRaises(ValueError, operator.setitem, o, slice(1, 3), (1, 2))
 
-        self.assertRaises(IndexError, operator.setitem, o, 6, 'x')
-        self.assertRaises(IndexError, operator.setitem, o, -7, 'x')
-        self.assertRaises(ValueError, operator.setitem, o, slice(1, 3), (1,2))
 
 if __name__ == "__main__":
     main()
