@@ -11,22 +11,23 @@ from PyObjCTest.corefoundation import *
 # registerCFSignature(name, encoding, typeId [, tollfreeName]) -> type
 
 CFUUIDRef = objc.registerCFSignature(
-        "CFUUIDRef",
-        OC_TestCoreFoundation.signatureForCFUUIDRef(),
-        OC_TestCoreFoundation.typeidForCFUUIDRef(),
-    )
+    "CFUUIDRef",
+    OC_TestCoreFoundation.signatureForCFUUIDRef(),
+    OC_TestCoreFoundation.typeidForCFUUIDRef(),
+)
 
 CFDateRef = objc.registerCFSignature(
-        "CFDateRef",
-        OC_TestCoreFoundation.signatureForCFDateRef(),
-        OC_TestCoreFoundation.typeidForCFDateRef(),
-        "NSDate",
-    )
+    "CFDateRef",
+    OC_TestCoreFoundation.signatureForCFDateRef(),
+    OC_TestCoreFoundation.typeidForCFDateRef(),
+    "NSDate",
+)
 
 if sys.version_info[0] == 3:
     unicode = str
 
-class TestCoreFoundation (TestCase):
+
+class TestCoreFoundation(TestCase):
     def testTollFree(self):
         obj = OC_TestCoreFoundation.today()
 
@@ -44,7 +45,7 @@ class TestCoreFoundation (TestCase):
 
         # Arggh, I'm an idiot: the code above doesn't calculate the same
         # string as the C code in corefoundation.m.
-        #print v , v2
+        # print v , v2
 
     def testBridged(self):
 
@@ -55,13 +56,14 @@ class TestCoreFoundation (TestCase):
         formatted = OC_TestCoreFoundation.formatUUID_(obj)
 
         self.assertIsInstance(formatted, unicode)
-        self.assertTrue( re.match(
-            r'[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}',
-            formatted) )
+        self.assertTrue(
+            re.match(
+                r"[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}", formatted
+            )
+        )
 
         self.assertRaises(objc.error, objc.lookUpClass, "CFUUIDRef")
 
-
         # AnotherUUID claims to return an Object (objc._C_ID), check that
         # we correctly return an object of the right type in that case as well.
         obj = OC_TestCoreFoundation.anotherUUID()
@@ -71,9 +73,11 @@ class TestCoreFoundation (TestCase):
         formatted = OC_TestCoreFoundation.formatUUID_(obj)
 
         self.assertIsInstance(formatted, unicode)
-        self.assertTrue( re.match(
-            r'[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}',
-            formatted) )
+        self.assertTrue(
+            re.match(
+                r"[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}", formatted
+            )
+        )
 
     # TODO: testcases that check that
     # 1) you cannot delete selectors
@@ -82,18 +86,19 @@ class TestCoreFoundation (TestCase):
     #
 
     def testMutableTypes(self):
-        cftype = objc.lookUpClass('NSCFType')
+        cftype = objc.lookUpClass("NSCFType")
 
         def myMethod(self, arg):
-            return '%s %s'%(self.__class__.__name__, arg)
+            return "%s %s" % (self.__class__.__name__, arg)
 
-        self.assertNotHasAttr(CFUUIDRef, 'myMethod')
+        self.assertNotHasAttr(CFUUIDRef, "myMethod")
 
         CFUUIDRef.myMethod = myMethod
 
-        self.assertHasAttr(CFUUIDRef, 'myMethod')
-        self.assertNotHasAttr(CFDateRef, 'myMethod')
-        self.assertNotHasAttr(cftype, 'myMethod')
+        self.assertHasAttr(CFUUIDRef, "myMethod")
+        self.assertNotHasAttr(CFDateRef, "myMethod")
+        self.assertNotHasAttr(cftype, "myMethod")
+
 
 if __name__ == "__main__":
     main()
