@@ -15,25 +15,32 @@ ctests = objc._ctests
 names = list(ctests.keys())
 methods = {}
 
+
 def do_exec(value, locals, globals):
 
     exec(value, locals, globals)
 
+
 def make_test(name):
     """
     Create a method for use in a unittest, the exec is needed to get the
     proper function name
     """
-    result = { 'meth': ctests[name] }
+    result = {"meth": ctests[name]}
 
-    if sys.platform == 'darwin' and name == 'CheckNSInvoke' and platform.machine() == 'Power Macintosh' and map(int, platform.mac_ver()[0].split('.')) < [10, 6]:
+    if (
+        sys.platform == "darwin"
+        and name == "CheckNSInvoke"
+        and platform.machine() == "Power Macintosh"
+        and tuple(map(int, platform.mac_ver()[0].split("."))) < (10, 5)
+    ):
         # There is a bug in Apple's implementation of NSInvocation
         # surpress the test failure until Apple fixes the class.
         # Don't change the C-code, the same function is used to disable
         # parts of the unittests that trigger the bug.
         def test_CheckNSInvoke(self):
             try:
-                ctests.CheckNSInvoke()
+                ctests["CheckNSInvoke"]()
             except AssertionError:
                 return
 
@@ -41,18 +48,23 @@ def make_test(name):
 
         return test_CheckNSInvoke
 
-    do_exec("""\
+    do_exec(
+        """\
 def test_%s(self):
     meth()
-"""%(name,), result, result)
+"""
+        % (name,),
+        result,
+        result,
+    )
 
-    return result['test_%s'%(name,)]
+    return result["test_%s" % (name,)]
 
 
 for n in names:
-    methods['test_%s'%(n,)] = make_test(n)
+    methods["test_%s" % (n,)] = make_test(n)
 
-CTests = type(TestCase)('CTests', (TestCase,), methods)
+CTests = type(TestCase)("CTests", (TestCase,), methods)
 
 if __name__ == "__main__":
     main()
