@@ -5,14 +5,21 @@ NOTE: this file is very, very incomplete and just tests copying at the moment.
 """
 import sys
 from PyObjCTools.TestSupport import *
-from PyObjCTest.fnd import NSDictionary, NSMutableDictionary, NSPredicate, NSObject, NSNull
+from PyObjCTest.fnd import (
+    NSDictionary,
+    NSMutableDictionary,
+    NSPredicate,
+    NSObject,
+    NSNull,
+)
 from PyObjCTest.pythonset import OC_TestSet
 import objc
 
 OC_PythonDictionary = objc.lookUpClass("OC_PythonDictionary")
 OC_BuiltinPythonDictionary = objc.lookUpClass("OC_BuiltinPythonDictionary")
 
-class TestDictionary (TestCase):
+
+class TestDictionary(TestCase):
     mapClass = dict
 
     def testCopy(self):
@@ -21,7 +28,7 @@ class TestDictionary (TestCase):
         self.assertEqual(s, o)
         self.assertIsNot(s, o)
 
-        s = self.mapClass({1:2, 'a':'c'})
+        s = self.mapClass({1: 2, "a": "c"})
         o = OC_TestSet.set_copyWithZone_(s, None)
         self.assertEqual(s, o)
         self.assertIsNot(s, o)
@@ -32,7 +39,7 @@ class TestDictionary (TestCase):
 
     def testMutableCopy(self):
 
-        s = self.mapClass({1:2, 'a':'c'})
+        s = self.mapClass({1: 2, "a": "c"})
         o = OC_TestSet.set_mutableCopyWithZone_(s, None)
         self.assertEqual(dict(s), o)
         self.assertIsNot(s, o)
@@ -45,7 +52,5 @@ class TestDictionary (TestCase):
         self.assertIsInstance(o, dict)
 
 
-
-
 if __name__ == "__main__":
     main()
