@@ -17,7 +17,8 @@ from PyObjCTools.TestSupport import *
 if sys.version_info[0] == 3:
     unicode = str
 
-class TestPythonRoundTrip (TestCase):
+
+class TestPythonRoundTrip(TestCase):
     # TODO: verify
 
     def testBasicPython(self):
@@ -28,12 +29,11 @@ class TestPythonRoundTrip (TestCase):
             container.setStoredObject_(v)
             self.assertTrue(v is container.storedObject(), repr(v))
 
-
     def testPythonContainer(self):
 
         container = OC_TestIdentity.alloc().init()
 
-        for v in ( [1, 2,3], (1,2,3), {1:2, 3:4} ):
+        for v in ([1, 2, 3], (1, 2, 3), {1: 2, 3: 4}):
             container.setStoredObject_(v)
             self.assertTrue(v is container.storedObject(), repr(v))
 
@@ -42,7 +42,7 @@ class TestPythonRoundTrip (TestCase):
 
         container = OC_TestIdentity.alloc().init()
 
-        for v in ( "Hello world", b"Hello world" ):
+        for v in ("Hello world", b"Hello world"):
             container.setStoredObject_(v)
             self.assertTrue(v is container.storedObject(), repr(v))
 
@@ -56,7 +56,7 @@ class TestPythonRoundTrip (TestCase):
             self.assertTrue(v is container.storedObject(), repr(v))
 
 
-class ObjCRoundTrip (TestCase):
+class ObjCRoundTrip(TestCase):
     # TODO: NSProxy
 
     def testNSObject(self):
@@ -97,6 +97,7 @@ class ObjCRoundTrip (TestCase):
         self.assertTrue(isinstance(v, objc.formal_protocol))
 
     if sys.maxsize < 2 ** 32 and os_release() < "10.7":
+
         def testObject(self):
             container = OC_TestIdentity.alloc().init()
             cls = objc.lookUpClass("Object")
@@ -153,10 +154,10 @@ class ObjCRoundTrip (TestCase):
         self.assertTrue(container.isSameObjectAsStored_(v), repr(v))
 
 
-class ObjCtoPython (TestCase):
+class ObjCtoPython(TestCase):
     # TODO: NSProxy
 
-    def assertFetchingTwice(self, container, message = None):
+    def assertFetchingTwice(self, container, message=None):
         v1 = container.storedObject()
         v2 = container.storedObject()
 
@@ -199,6 +200,7 @@ class ObjCtoPython (TestCase):
         self.assertFetchingTwice(container, "protocol")
 
     if sys.maxsize < 2 ** 32 and os_release() < "10.7":
+
         def testObject(self):
             container = OC_TestIdentity.alloc().init()
 
@@ -246,7 +248,8 @@ class ObjCtoPython (TestCase):
         container.setStoredObjectToResultOf_on_("zero", cls)
         self.assertFetchingTwice(container, "decimal")
 
-class PythonToObjC (TestCase):
+
+class PythonToObjC(TestCase):
     # TODO: verify
 
     def testPlainObjects(self):
@@ -257,11 +260,10 @@ class PythonToObjC (TestCase):
 
             self.assertTrue(container.isSameObjectAsStored_(v), repr(v))
 
-
     def testContainers(self):
         container = OC_TestIdentity.alloc().init()
 
-        for v in ([1,2,3], (1,2,3), {1:2, 3:4}):
+        for v in ([1, 2, 3], (1, 2, 3), {1: 2, 3: 4}):
             container.setStoredObject_(v)
 
             self.assertTrue(container.isSameObjectAsStored_(v), repr(v))
@@ -279,12 +281,13 @@ class PythonToObjC (TestCase):
         # These get converted, not proxied
         container = OC_TestIdentity.alloc().init()
 
-        for v in (1, 666666, sys.maxsize*3, 1.0,):
+        for v in (1, 666_666, sys.maxsize * 3, 1.0):
             container.setStoredObject_(v)
 
             self.assertTrue(container.isSameObjectAsStored_(v), repr(v))
 
-class TestSerializingDataStructures (TestCase):
+
+class TestSerializingDataStructures(TestCase):
     # OC_Python{Array,Dictionary} used to contain specialized
     # identity-preservation code. It is unclear why this was added, it might
     # have to do with writing data to plist files.
@@ -298,23 +301,16 @@ class TestSerializingDataStructures (TestCase):
     def testMakePlist(self):
         container = OC_TestIdentity.alloc().init()
 
-        value = [ 1, 2, 3, [ "hello", ["world", ("in", 9 ) ], True, {"aap":3}]]
+        value = [1, 2, 3, ["hello", ["world", ("in", 9)], True, {"aap": 3}]]
         value.append(value[3])
 
         container.setStoredObject_(value)
         container.writeStoredObjectToFile_("/tmp/pyPyObjCTest.identity")
 
-        value = {
-            "hello": [ 1, 2, 3],
-            "world": {
-                "nl": "wereld",
-                "de": "Welt",
-            }
-        }
+        value = {"hello": [1, 2, 3], "world": {"nl": "wereld", "de": "Welt"}}
         container.setStoredObject_(value)
         container.writeStoredObjectToFile_("/tmp/pyPyObjCTest.identity")
 
 
-
 if __name__ == "__main__":
     main()
