@@ -5,7 +5,8 @@ from PyObjCTest.structpointer1 import OC_TestStructPointer
 import objc
 import warnings
 
-class TestObjCPointer (TestCase):
+
+class TestObjCPointer(TestCase):
     def setUp(self):
         self._unknown_pointer_raises = objc.options.unknown_pointer_raises
 
@@ -16,8 +17,8 @@ class TestObjCPointer (TestCase):
         self.assertEqual(objc.options.unknown_pointer_raises, False)
 
     def test_class_introspection(self):
-        self.assertIn('type', dir(objc.ObjCPointer))
-        self.assertIn('pointerAsInteger', dir(objc.ObjCPointer))
+        self.assertIn("type", dir(objc.ObjCPointer))
+        self.assertIn("pointerAsInteger", dir(objc.ObjCPointer))
 
     def test_objc_pointer_creation(self):
         with warnings.catch_warnings():
