@@ -5,10 +5,10 @@ from PyObjCTest.opaque import *
 
 FooHandle = objc.createOpaquePointerType("FooHandle", FooEncoded, "FooHandle doc")
 
-class TestFromPython (TestCase):
-    def testBasic (self):
-        tp = objc.createOpaquePointerType(
-                "BarHandle", BarEncoded, "BarHandle doc")
+
+class TestFromPython(TestCase):
+    def testBasic(self):
+        tp = objc.createOpaquePointerType("BarHandle", BarEncoded, "BarHandle doc")
 
         self.assertIsInstance(tp, type)
         self.assertEqual(tp.__module__, "objc")
@@ -24,37 +24,38 @@ class TestFromPython (TestCase):
         # NULL pointer is converted to None
         self.assertEqual(OC_OpaqueTest.nullBar(), None)
 
-    def testNaming (self):
-        tp = objc.createOpaquePointerType(
-                "Mod.BarHandle", BarEncoded, "BarHandle doc")
+    def testNaming(self):
+        tp = objc.createOpaquePointerType("Mod.BarHandle", BarEncoded, "BarHandle doc")
 
         self.assertIsInstance(tp, type)
         self.assertEqual(tp.__module__, "Mod")
         self.assertEqual(tp.__name__, "BarHandle")
-        if sys.version_info[:2] >= (3,3):
+        if sys.version_info[:2] >= (3, 3):
             self.assertEqual(tp.__qualname__, "BarHandle")
         self.assertEqual(repr(tp), "<class 'Mod.BarHandle'>")
 
-class TestFromC (TestCase):
+
+class TestFromC(TestCase):
     def testMutable(self):
         self.assertIsInstance(FooHandle, type)
 
         def create(cls, value):
             return OC_OpaqueTest.createFoo_(value)
+
         FooHandle.create = classmethod(create)
         FooHandle.delete = lambda self: OC_OpaqueTest.deleteFoo_(self)
         FooHandle.get = lambda self: OC_OpaqueTest.getValueOf_(self)
         FooHandle.set = lambda self, v: OC_OpaqueTest.setValue_forFoo_(v, self)
 
-        self.assertHasAttr(FooHandle, 'create')
-        self.assertHasAttr(FooHandle, 'delete')
+        self.assertHasAttr(FooHandle, "create")
+        self.assertHasAttr(FooHandle, "delete")
 
         f = FooHandle.create(42)
         self.assertIsInstance(f, FooHandle)
-        self.assertEqual( f.get(), 42 )
+        self.assertEqual(f.get(), 42)
 
         f.set(f.get() + 20)
-        self.assertEqual( f.get(), 62 )
+        self.assertEqual(f.get(), 62)
 
         FooHandle.__int__ = lambda self: self.get()
         FooHandle.__getitem__ = lambda self, x: self.get() * x
@@ -65,7 +66,7 @@ class TestFromC (TestCase):
     def testBasic(self):
         f = OC_OpaqueTest.createFoo_(99)
         self.assertIsInstance(f, FooHandle)
-        self.assertEqual( OC_OpaqueTest.getValueOf_(f), 99 )
+        self.assertEqual(OC_OpaqueTest.getValueOf_(f), 99)
 
         self.assertHasAttr(f, "__pointer__")
         if sys.version_info[0] == 2:
@@ -79,14 +80,15 @@ class TestFromC (TestCase):
         # There is no exposed type object that for PyCObject, test the
         # type name instead
         if sys.version_info[0] == 2 and sys.version_info[1] < 7:
-            self.assertEqual( type(f.__cobject__()).__name__, 'PyCObject' )
+            self.assertEqual(type(f.__cobject__()).__name__, "PyCObject")
         else:
-            self.assertEqual( type(f.__cobject__()).__name__, 'PyCapsule' )
+            self.assertEqual(type(f.__cobject__()).__name__, "PyCapsule")
 
         # Check round tripping through a PyCObject.
         co = f.__cobject__()
         g = FooHandle(co)
         self.assertEqual(f.__pointer__, g.__pointer__)
 
+
 if __name__ == "__main__":
     main()
