@@ -2,9 +2,12 @@ from PyObjCTools.TestSupport import *
 import objc
 from PyObjCTest.testoutputinitializer import PyObjC_TestOutputInitializer
 
-objc.registerMetaDataForSelector(b"PyObjC_TestOutputInitializer",
-        b"initWithBooleanOutput:", dict(arguments={
-            2: dict(type_modifier=b'o')}))
+objc.registerMetaDataForSelector(
+    b"PyObjC_TestOutputInitializer",
+    b"initWithBooleanOutput:",
+    dict(arguments={2: dict(type_modifier=b"o")}),
+)
+
 
 class TestOutputInitializer(TestCase):
     def testOutputInitializer(self):
@@ -12,5 +15,6 @@ class TestOutputInitializer(TestCase):
         self.assertEqual(rtrue, objc.YES)
         self.assertEqual(robj.isInitialized(), objc.YES)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
