@@ -4,11 +4,11 @@ import objc
 import sys
 
 # Most useful systems will at least have 'NSObject'.
-#NSObject = objc.lookUpClass('NSObject')
+# NSObject = objc.lookUpClass('NSObject')
 
 # Use a class that isn't used in the rest of the testsuite,
 # should write a native class for this!
-BaseName = 'NSAttributedString'
+BaseName = "NSAttributedString"
 BaseClass = objc.lookUpClass(BaseName)
 
 if sys.maxsize >= 2 ** 32:
@@ -18,15 +18,15 @@ if sys.maxsize >= 2 ** 32:
     pass
 
 else:
+
     class TestPosing(TestCase):
         def testPosing(self):
-
             class PoseClass(BaseClass):
                 __slots__ = ()  # Don't add instance variables, not even __dict__
+
                 def testPosingMethod(self):
                     return "<PoseClass instance>"
 
-
             PoseClass.poseAsClass_(BaseClass)
 
             # BaseClass still refers to the old class, if we look it up again
@@ -36,12 +36,11 @@ else:
 
             # XXX: next assertion fails because the runtime seems to copy the
             # original class.
-            #self.assertIsInstance(obj, PoseClass)
+            # self.assertIsInstance(obj, PoseClass)
             self.assertNotEqual(BaseClass.__name__, BaseName)
             self.assertEqual(PoseClass.__name__, BaseName)
             del obj
 
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
