@@ -7,7 +7,7 @@ from fnmatch import fnmatch
 import unittest
 import dejagnu
 
-deja_suite = dejagnu.testSuiteForDirectory('tests/testsuite/libffi.call')
-suite = unittest.TestSuite((deja_suite, ))
+deja_suite = dejagnu.testSuiteForDirectory("tests/testsuite/libffi.call")
+suite = unittest.TestSuite((deja_suite,))
 runner = unittest.TextTestRunner(verbosity=1)
 runner.run(suite)
